from django.urls import path

from kaf_pas.planing.views import operations_plan_refs

urlpatterns = [

    path('OperationsPlanRefs/Fetch/', operations_plan_refs.Operations_plan_refs_Fetch),
    path('OperationsPlanRefs/Add', operations_plan_refs.Operations_plan_refs_Add),
    path('OperationsPlanRefs/Update', operations_plan_refs.Operations_plan_refs_Update),
    path('OperationsPlanRefs/Remove', operations_plan_refs.Operations_plan_refs_Remove),
    path('OperationsPlanRefs/Lookup/', operations_plan_refs.Operations_plan_refs_Lookup),
    path('OperationsPlanRefs/Info/', operations_plan_refs.Operations_plan_refs_Info),
    path('OperationsPlanRefs/Copy', operations_plan_refs.Operations_plan_refs_Copy),

]



from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
from isc_common.http.RPCResponse import RPCResponseConstant
from isc_common.http.response import JsonResponse
from kaf_pas.planing.models.operations_plan_qtys import Operations_plan_qtys


class Operations_plan_qtysManager(object):
    pass


@JsonResponseWithException()
def Operations_plan_qtys_Fetch(request):
    return JsonResponse(
        DSResponse(
            request=request,
            data=Operations_plan_qtys.objects.
                select_related().
                get_range_rows1(
                request=request,
                function=Operations_plan_qtysManager.getRecord
            ),
            status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Operations_plan_qtys_Add(request):
    return JsonResponse(DSResponseAdd(data=Operations_plan_qtys.objects.createFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Operations_plan_qtys_Update(request):
    return JsonResponse(DSResponseUpdate(data=Operations_plan_qtys.objects.updateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Operations_plan_qtys_Remove(request):
    return JsonResponse(DSResponse(request=request, data=Operations_plan_qtys.objects.deleteFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Operations_plan_qtys_Lookup(request):
    return JsonResponse(DSResponse(request=request, data=Operations_plan_qtys.objects.lookupFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Operations_plan_qtys_Info(request):
    return JsonResponse(DSResponse(request=request, data=Operations_plan_qtys.objects.get_queryset().get_info(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Operations_plan_qtys_Copy(request):
    return JsonResponse(DSResponse(request=request, data=Operations_plan_qtys.objects.copyFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)



import logging

from django.db.models import DecimalField

from isc_common.fields.related import ForeignKeyProtect
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
from isc_common.models.audit import AuditModel
from kaf_pas.ckk.models.ed_izm import Ed_izm
from kaf_pas.ckk.models.material_askon import Material_askon
from kaf_pas.ckk.models.materials import Materials
from kaf_pas.production.models.operations import Operations

logger = logging.getLogger(__name__)


class Operation_materialQuerySet(CommonManagetWithLookUpFieldsQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class Operation_materialManager(CommonManagetWithLookUpFieldsManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'material_askon_id': record.material_askon.id if record.material_askon else None,
            'material_askon__field0': record.material_askon.field0 if record.material_askon else None,
            'material_id': record.material.id if record.material else None,
            'material__name': record.material.name if record.material else None,
            'complex_name': record.complex_name,
            'complex_gost': record.complex_gost,
            'ed_izm_id': record.ed_izm.id,
            'ed_izm__code': record.ed_izm.code,
            'ed_izm__name': record.ed_izm.name,
            'qty': record.qty,
        }
        return res

    def get_queryset(self):
        return Operation_materialQuerySet(self.model, using=self._db)


class Operation_material(AuditModel):
    operation = ForeignKeyProtect(Operations)
    material = ForeignKeyProtect(Materials, null=True, blank=True)
    material_askon = ForeignKeyProtect(Material_askon, null=True, blank=True)
    ed_izm = ForeignKeyProtect(Ed_izm, default=None)
    qty = DecimalField(max_digits=10, decimal_places=4, default=0.0)

    @property
    def complex_name(self):
        if self.material:
            return f'{self.material.materials_type.full_name}{self.material.full_name}'
        else:
            return None

    @property
    def complex_gost(self):
        if self.material:
            if self.material.materials_type.gost:
                return f'{self.material.materials_type.gost} / {self.material.gost}'
            else:
                return f'{self.material.gost}'
        else:
            return None

    objects = Operation_materialManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Кросс таблица'



from django.urls import path

from kaf_pas.planing.views import operations_plan_qtys

urlpatterns = [

    path('Operations_plan_qtys/Fetch/', operations_plan_qtys.Operations_plan_qtys_Fetch),
    path('Operations_plan_qtys/Add', operations_plan_qtys.Operations_plan_qtys_Add),
    path('Operations_plan_qtys/Update', operations_plan_qtys.Operations_plan_qtys_Update),
    path('Operations_plan_qtys/Remove', operations_plan_qtys.Operations_plan_qtys_Remove),
    path('Operations_plan_qtys/Lookup/', operations_plan_qtys.Operations_plan_qtys_Lookup),
    path('Operations_plan_qtys/Info/', operations_plan_qtys.Operations_plan_qtys_Info),
    path('Operations_plan_qtys/Copy', operations_plan_qtys.Operations_plan_qtys_Copy),

]



import logging

from isc_common.fields.related import ForeignKeyCascade, ForeignKeyProtect
from isc_common.models.audit import AuditModel
from kaf_pas.ckk.models.item import Item

logger = logging.getLogger(__name__)


class Item_refs(AuditModel):
    child = ForeignKeyProtect(Item, related_name='child')
    parent = ForeignKeyProtect(Item, related_name='parent', blank=True, null=True)

    def __str__(self):
        return f'\nID={self.id} child=[{self.child}], parent=[{self.parent}]'

    def save(self, *args, **kwargs):
        if self.parent:
            if self.parent.id == self.child.id:
                raise Exception(f'parent.id ({self.parent.id}) == child.id ({self.child.id})')
        super().save(*args, **kwargs)

    class Meta:
        verbose_name = 'Item_refs'
        unique_together = ('child', 'parent')



from clndr.models.calendars import Calendars
from isc_common.http.DSResponse import DSResponse, JsonResponseWithException
from isc_common.http.RPCResponse import RPCResponseConstant
from isc_common.http.response import JsonResponse


@JsonResponseWithException()
def CalendarGraph_Fetch(request):
    return JsonResponse(
        DSResponse(
            request=request,
            data=Calendars.objects.
                filter().
                get_graph(request=request),
            status=RPCResponseConstant.statusSuccess).response)



import logging

from bitfield import BitField, BitHandler
from django.db import transaction
from django.db.models import PositiveIntegerField
from django.forms import model_to_dict

from isc_common import getAttr, setAttr, delAttr
from isc_common.fields.related import ForeignKeyProtect
from isc_common.http.DSRequest import DSRequest
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
from isc_common.models.audit import AuditModel
from kaf_pas.kd.models.document_attributes import Document_attributes
from kaf_pas.kd.models.documents import Documents

logger = logging.getLogger(__name__)


class ItemQuerySet(CommonManagetWithLookUpFieldsQuerySet):
    # def replace(self, *args, **kwargs):
    #     return super().filter(*args, **kwargs)

    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class ItemManager(CommonManagetWithLookUpFieldsManager):

    def createFromRequest(self, request):
        request = DSRequest(request=request)
        data = request.get_data()
        _data = data.copy()

        parent = _data.get('parent')
        if parent:
            delAttr(_data, 'parent')
            setAttr(_data, 'parent_id', parent)

        delAttr(_data, 'STMP_1__value_str')
        delAttr(_data, 'STMP_2__value_str')

        relevant = data.get('relevant')
        props = 1

        if relevant:
            if relevant == 'Актуален':
                props |= Item.props.relevant
            else:
                props &= ~Item.props.relevant

        where_from = data.get('where_from')
        if where_from == 'Получено из чертежа':
            props |= Item.props.from_cdw
        elif where_from == 'Получено из спецификации':
            props |= Item.props.from_spw
        elif where_from == 'Получено из бумажного архива':
            props |= Item.props.from_pdf
        elif where_from == 'Занесено вручную':
            props |= Item.props.man_input

        delAttr(_data, 'relevant')
        delAttr(_data, 'where_from')
        setAttr(_data, 'props', props)

        res = super().create(**_data)
        logger.debug(f'Added: {res}')

        from kaf_pas.ckk.models.item_refs import Item_refs
        item_refs, create = Item_refs.objects.get_or_create(parent_id=_data.get('parent_id'), child=res)
        if create:
            logger.debug(f'Added item_ref: {item_refs}')

        res = model_to_dict(res)

        props = getAttr(res, 'props')
        if props and isinstance(props, BitHandler):
            props = getAttr(res, 'props')._value
            setAttr(res, 'props', props)
        setAttr(res, 'isFolder', False)
        data.update(res)
        return data

    @staticmethod
    def delete_recursive(item, delete_lenes=False):
        with transaction.atomic():
            from kaf_pas.ckk.models.item_image_refs import Item_image_refs
            from kaf_pas.ckk.models.item_line import Item_line
            # from kaf_pas.ckk.models.item_location import Item_location
            from kaf_pas.ckk.models.item_refs import Item_refs

            Item_image_refs.objects.filter(item=item).delete()

            if delete_lenes:
                Item_line.objects.filter(parent=item).delete()
                Item_line.objects.filter(child=item).delete()

            Item_refs.objects.filter(parent=item).delete()
            Item_refs.objects.filter(child=item).delete()

            # Item_location.objects.filter(item=item).delete()
            item.delete()

    def updateFromRequest(self, request, removed=None, function=None):
        from kaf_pas.ckk.models.item_refs import Item_refs
        from kaf_pas.ckk.models.item_line import Item_line

        if not isinstance(request, DSRequest):
            request = DSRequest(request=request)
        data = request.get_data()

        with transaction.atomic():
            targetRecord = data.get('targetRecord')
            dropRecords = data.get('dropRecords')
            if data.get('mode') == 'move':
                res = 0
                for dropRecord in dropRecords:
                    res += Item_refs.objects.filter(parent_id=dropRecord.get('parent_id'), child_id=dropRecord.get('id')).update(parent_id=targetRecord.get('id'))
                    res += Item_line.objects.filter(parent_id=dropRecord.get('parent_id'), child_id=dropRecord.get('id')).update(parent_id=targetRecord.get('id'))
                return res
            elif data.get('mode') == 'copy':
                res = 0
                for dropRecord in dropRecords:
                    Item_refs.objects.create(parent_id=targetRecord.get('id'), child_id=dropRecord.get('id'))
                    res += 1
                return res
            elif data.get('mode') == 'replace':
                res = 0
                for dropRecord in dropRecords:
                    Item_refs.objects.create(parent_id=targetRecord.get('parent_id'), child_id=dropRecord.get('id'))
                    res += 1

                    item_line = model_to_dict(Item_line.objects.get(parent_id=targetRecord.get('parent_id'), child_id=targetRecord.get('id')))
                    delAttr(item_line, 'id')
                    delAttr(item_line, 'parent')
                    delAttr(item_line, 'child')
                    setAttr(item_line, 'parent_id', targetRecord.get('parent_id'))
                    setAttr(item_line, 'child_id', dropRecord.get('id'))
                    setAttr(item_line, 'SPC_CLM_NAME_id', dropRecord.get('STMP_1_id'))
                    delAttr(item_line, 'SPC_CLM_NAME')
                    setAttr(item_line, 'SPC_CLM_MARK_id', dropRecord.get('STMP_2_id'))
                    delAttr(item_line, 'SPC_CLM_MARK')
                    setAttr(item_line, 'SPC_CLM_FORMAT_id', getAttr(item_line, 'SPC_CLM_FORMAT'))
                    delAttr(item_line, 'SPC_CLM_FORMAT')
                    setAttr(item_line, 'SPC_CLM_ZONE_id', getAttr(item_line, 'SPC_CLM_ZONE'))
                    delAttr(item_line, 'SPC_CLM_ZONE')
                    setAttr(item_line, 'SPC_CLM_POS_id', getAttr(item_line, 'SPC_CLM_POS'))
                    delAttr(item_line, 'SPC_CLM_POS')
                    setAttr(item_line, 'SPC_CLM_COUNT_id', getAttr(item_line, 'SPC_CLM_COUNT'))
                    delAttr(item_line, 'SPC_CLM_COUNT')
                    setAttr(item_line, 'SPC_CLM_NOTE_id', getAttr(item_line, 'SPC_CLM_NOTE'))
                    delAttr(item_line, 'SPC_CLM_NOTE')
                    setAttr(item_line, 'SPC_CLM_MASSA_id', getAttr(item_line, 'SPC_CLM_MASSA'))
                    delAttr(item_line, 'SPC_CLM_MASSA')
                    setAttr(item_line, 'SPC_CLM_MATERIAL_id', getAttr(item_line, 'SPC_CLM_MATERIAL'))
                    delAttr(item_line, 'SPC_CLM_MATERIAL')
                    setAttr(item_line, 'SPC_CLM_USER_id', getAttr(item_line, 'SPC_CLM_USER'))
                    delAttr(item_line, 'SPC_CLM_USER')
                    setAttr(item_line, 'SPC_CLM_KOD_id', getAttr(item_line, 'SPC_CLM_KOD'))
                    delAttr(item_line, 'SPC_CLM_KOD')
                    setAttr(item_line, 'SPC_CLM_FACTORY_id', getAttr(item_line, 'SPC_CLM_FACTORY'))
                    delAttr(item_line, 'SPC_CLM_FACTORY')
                    Item_line.objects.create(**item_line)
                    res += 1

                    Item_refs.objects.filter(parent_id=targetRecord.get('parent_id'), child_id=targetRecord.get('id')).delete()
                    Item_line.objects.filter(parent_id=targetRecord.get('parent_id'), child_id=targetRecord.get('id')).delete()

                    try:
                        Item.objects.filter(id=targetRecord.get('id')).delete()
                    except Exception as ex:
                        logger.debug(ex)

                return res

            else:
                relevant = data.get('relevant')
                props = data.get('props')

                if relevant == 'Актуален':
                    props |= Item.props.relevant
                else:
                    props &= ~Item.props.relevant

                where_from = data.get('where_from')
                if where_from == 'Получено из чертежа':
                    props |= Item.props.from_cdw
                elif where_from == 'Получено из спецификации':
                    props |= Item.props.from_spw
                elif where_from == 'Получено из бумажного архива':
                    props |= Item.props.from_pdf
                elif where_from == 'Занесено вручную':
                    props |= Item.props.man_input

                delAttr(data, 'relevant')
                delAttr(data, 'where_from')
                setAttr(data, 'props', props)
                res = self.filter(id=data.get('id')).update(**data)

            return res

    def deleteFromRequest(self, request, removed=None, ):
        request = DSRequest(request=request)
        data = request.get_data()
        res = 0
        if data.get('mode') == 'deleteInner':
            record = data.get('record')

            from kaf_pas.ckk.models.item_refs import Item_refs
            res, _ = Item_refs.objects.filter(child_id=record.get('id'), parent_id=record.get('parent_id')).delete()
            return res

        with transaction.atomic():
            for id, mode in request.get_tuple_ids():
                if mode == 'hide':
                    res += super().filter(id=id).soft_delete()
                else:
                    from kaf_pas.ckk.models.item_refs import Item_refs
                    for parent in Item_refs.objects.filter(child_id=id):
                        res, _ = Item_refs.objects.filter(child_id=id, parent_id=parent.id).delete()
                        from kaf_pas.ckk.models.item_line import Item_line
                        res1, _ = Item_line.objects.filter(child_id=id, parent_id=parent.id).delete()
                        res += res1
                    res = super().filter(id=id).delete()[0]

        return res


@staticmethod
def getRecord(record):
    res = {
        'id': record.id,
        'STMP_1_id': record.STMP_1.id if record.STMP_1 else None,
        'STMP_1__value_str': record.STMP_1.value_str if record.STMP_1 else None,
        'STMP_2_id': record.STMP_2.id if record.STMP_2 else None,
        'STMP_2__value_str': record.STMP_2.value_str if record.STMP_2 else None,
        'lastmodified': record.lastmodified,
        'version': record.version,
        'document_id': record.document.id if record.document else None,
        'document__file_document': record.document.file_document if record.document else None,
        'editing': record.editing,
        'deliting': record.deliting,
    }
    return res


def get_queryset(self):
    return ItemQuerySet(self.model, using=self._db)


class Item_add:
    @staticmethod
    def get_prop_field():
        return BitField(flags=(
            ('relevant', 'Актуальность'),  # 1
            ('from_cdw', 'Получено из чертежа'),  # 2
            ('from_spw', 'Получено из спецификации'),  # 4
            ('for_line', 'Строка спецификации'),  # 8
            ('from_pdf', 'Получено из бумажного архива'),  # 16
            ('man_input', 'Занесено вручную'),  # 32
        ), default=1, db_index=True)


class Item(AuditModel):
    STMP_1 = ForeignKeyProtect(Document_attributes, verbose_name='Наименование изделия', related_name='STMP_1', null=True, blank=True)
    STMP_2 = ForeignKeyProtect(Document_attributes, verbose_name='Обозначение изделия', related_name='STMP_2', null=True, blank=True)
    version = PositiveIntegerField(null=True, blank=True)

    props = Item_add.get_prop_field()

    document = ForeignKeyProtect(Documents, verbose_name='Документ', null=True, blank=True)

    objects = ItemManager()

    @staticmethod
    def get_vaslue_str(doc_attr):
        if doc_attr.value_str == None:
            return None
        return doc_attr.value_str.strip() if doc_attr else None

    def save(self, *args, **kwargs):
        if ~self.props.relevant:
            item = Item.objects.filter()
            from django.db.models import Max

            res = item.aggregate(Max('version'))
            self.version = 1 if not res.get('version__max') else res.get('version__max') + 1
        super().save(*args, **kwargs)

    def __str__(self):
        return f'ID={self.id} STMP_1=[{self.STMP_1}], STMP_2=[{self.STMP_2}], props={self.props}, version={self.version}'

    class Meta:
        verbose_name = 'Товарная позиция'
        unique_together = ('STMP_1', 'STMP_2', 'props', 'version')



from django.urls import path

from kaf_pas.planing.views import operations_plan_status

urlpatterns = [

    path('OperationsPlanStatus/Fetch/', operations_plan_status.OperationsPlanStatus_Fetch),
    path('OperationsPlanStatus/Add', operations_plan_status.OperationsPlanStatus_Add),
    path('OperationsPlanStatus/Update', operations_plan_status.OperationsPlanStatus_Update),
    path('OperationsPlanStatus/Remove', operations_plan_status.OperationsPlanStatus_Remove),
    path('OperationsPlanStatus/Lookup/', operations_plan_status.OperationsPlanStatus_Lookup),
    path('OperationsPlanStatus/Info/', operations_plan_status.OperationsPlanStatus_Info),
    path('OperationsPlanStatus/Copy', operations_plan_status.OperationsPlanStatus_Copy),

]



import logging

from django.db.models import DecimalField

from isc_common.fields.code_field import CodeStrictField
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
from isc_common.models.base_ref import BaseRefHierarcy

logger = logging.getLogger(__name__)


class Ed_izmQuerySet(CommonManagetWithLookUpFieldsQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class Ed_izmManager(CommonManagetWithLookUpFieldsManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'code': record.code,
            'name': record.name,
            'koef_recalc': record.koef_recalc,
            'description': record.description,
            'parent_id': record.parent.id if record.parent else None
        }
        return res

    def get_queryset(self):
        return Ed_izmQuerySet(self.model, using=self._db)


class Ed_izm(BaseRefHierarcy):
    code = CodeStrictField(unique=True)
    koef_recalc = DecimalField(max_digits=19, decimal_places=4, null=True, blank=True)
    objects = Ed_izmManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Единицы измерения'



from django.utils.translation import ugettext_lazy as _

import logging

from isc_common.models.base_ref import BaseRefManager, BaseRef, BaseRefQuerySet

logger = logging.getLogger(__name__)


class StatusPrecentQuerySet(BaseRefQuerySet):
    def delete(self):
        return super().delete()

    def create(self, **kwargs):
        return super().create(**kwargs)

    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class StatusPrecentManager(BaseRefManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'code': record.code,
            'name': record.name,
            'description': record.description,
        }
        return res

    def get_queryset(self):
        return StatusPrecentQuerySet(self.model, using=self._db)


class StatusPrecent(BaseRef):
    objects = StatusPrecentManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Статусы распоряжения'



import logging

from django.db.models import DateTimeField, DecimalField
from django.utils import timezone

from isc_common.fields.related import ForeignKeyProtect
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsQuerySet, CommonManagetWithLookUpFieldsManager
from isc_common.models.audit import AuditModel
from kaf_pas.ckk.models.item import Item
from kaf_pas.ckk.models.locations import Locations
from kaf_pas.ckk.models.status import Status
from kaf_pas.planing.models.operation_plan_types import Operation_plan_types
from kaf_pas.planing.models.operations_plan_status import OperationsPlanStatus

logger = logging.getLogger(__name__)


class OperationsPlanQuerySet(CommonManagetWithLookUpFieldsQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class OperationsPlanManager(CommonManagetWithLookUpFieldsManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'code': record.code,
            'name': record.name,
            'quantity': record.quantity,
            'description': record.description,
        }
        return res

    def get_queryset(self):
        return OperationsPlanQuerySet(self.model, using=self._db)


class OperationsPlan(AuditModel):
    status = ForeignKeyProtect(OperationsPlanStatus)

    opertype = ForeignKeyProtect(Operation_plan_types)

    objects = OperationsPlanManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Операции планировая'



from django.urls import path

from kaf_pas.production.views import operations_refs

urlpatterns = [

    path('operations_refs/Fetch/', operations_refs.Operations_refs_Fetch),
    path('operations_refs/Add', operations_refs.Operations_refs_Add),
    path('operations_refs/Update', operations_refs.Operations_refs_Update),
    path('operations_refs/Remove', operations_refs.Operations_refs_Remove),
    path('operations_refs/Lookup/', operations_refs.Operations_refs_Lookup),
    path('operations_refs/Info/', operations_refs.Operations_refs_Info),

]



import logging

import requests
from django.conf import settings
from django.http import HttpResponseRedirect

from isc_common import ws

logger = logging.getLogger(__name__)


def download_attach_file(request, id):
    ws_channel = request.session.get('ws_channel')
    ws_port = request.session.get('ws_port')
    host = ws.WS_HOST

    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/DocumentsThumb/Download/{id}/', params=dict(port=ws_port, ws_channel=ws_channel, host=host))
    return HttpResponseRedirect(f'{settings.KOMPAS_INFORMICA}/logic/DocumentsThumb/Download/{id}/')


def download_attach_file_10(request, id):
    ws_channel = request.session.get('ws_channel')
    ws_port = request.session.get('ws_port')
    host = ws.WS_HOST

    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/DocumentsThumb/Download10/{id}/', params=dict(port=ws_port, ws_channel=ws_channel, host=host))
    return HttpResponseRedirect(r.url)



import logging

from django.db.models import BooleanField

from isc_common.fields.related import ForeignKeyProtect
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsQuerySet, CommonManagetWithLookUpFieldsManager
from isc_common.models.base_ref import BaseRefHierarcy
from kaf_pas.ckk.models.locations import Locations

logger = logging.getLogger(__name__)


class Resource_viewQuerySet(CommonManagetWithLookUpFieldsQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class Resource_viewManager(CommonManagetWithLookUpFieldsManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'code': record.code,
            'name': record.name,
            'full_name': record.full_name,
            'description': record.description,
            'isFolder': record.isFolder,
            # "location_id": record.location.id,
            # "location__code": record.location.code,
            # "location__name": record.location.name,
            # "location__full_name": record.location.full_name,
            'parent_id': record.parent.id if record.parent else None
        }
        return res

    def get_queryset(self):
        return Resource_viewQuerySet(self.model, using=self._db)

    @property
    def full_name(self):
        return f'{self.location.full_name}/{super().full_name}'


class Resource_view(BaseRefHierarcy):
    location = ForeignKeyProtect(Locations)
    isFolder = BooleanField()

    objects = Resource_viewManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        db_table = 'production_resource_view'
        managed = False
        verbose_name = 'Ресурсы'



from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
from isc_common.http.RPCResponse import RPCResponseConstant
from isc_common.http.response import JsonResponse
from kaf_pas.ckk.models.copyItems import CopyItems
from kaf_pas.ckk.models.item import Item
from kaf_pas.ckk.models.item_view import Item_view, Item_viewManager


def Item_view_query():
    query = Item_view.objects.filter()
    return query


@JsonResponseWithException()
def Item_view_Fetch(request):
    return JsonResponse(
        DSResponse(
            request=request,
            data=Item_view_query().
                get_range_rows1(
                request=request,
                function=Item_viewManager.getRecord,
                distinct_field_names=('id',)
            ),
            status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Item_view_Add(request):
    return JsonResponse(DSResponseAdd(data=Item.objects.createFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Item_view_Update(request):
    return JsonResponse(DSResponseUpdate(data=Item.objects.updateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Item_view_Remove(request):
    return JsonResponse(DSResponse(request=request, data=Item.objects.deleteFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Item_view_Lookup(request):
    return JsonResponse(DSResponse(request=request, data=Item.objects.lookupFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Item_view_Info(request):
    return JsonResponse(DSResponse(request=request, data=Item_view_query().get_info(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException(printing=False)
def copyItems(request):
    return JsonResponse(CopyItems(request).response)



import logging

from django.db import transaction
from django.db.models import TextField

from isc_common.fields.related import ForeignKeyProtect
from isc_common.http.DSRequest import DSRequest
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
from isc_common.models.audit import AuditModel
from kaf_pas.ckk.models.attr_type import Attr_type

logger = logging.getLogger(__name__)


class Document_attributesQuerySet(CommonManagetWithLookUpFieldsQuerySet):
    pass


class Document_attributesManager(CommonManagetWithLookUpFieldsManager):
    def get_queryset(self):
        return Document_attributesQuerySet(self.model, using=self._db)

    @staticmethod
    def getRecord(record):
        res = {
            "id": record.id,
            "attr_type_id": record.attr_type.id,
            "attr_type__code": record.attr_type.code,
            "attr_type__name": record.attr_type.name,
            "attr_type__description": record.attr_type.description if record.attr_type else None,
            "value_str": record.value_str,
            "lastmodified": record.lastmodified,
            "editing": record.editing,
            "deliting": record.deliting,
        }
        return res

    def update_document_attributes(self, document_attribute):
        with transaction.atomic():
            # for document_attribute_old in super().filter(
            #         attr_type_id=document_attribute.get('attr_type_id'),
            #         value_str=document_attribute.get('value_str')).select_for_update():
            #
            #     for item in Item.objects.filter(STMP_1=document_attribute_old).select_for_update():
            #         item.STMP_1_id = document_attribute.get('id')
            #         item.save()
            #
            #     for item in Item.objects.filter(STMP_2=document_attribute_old).select_for_update():
            #         item.STMP_2 = document_attribute.get('id')
            #         item.save()
            #
            #     for item_line in Item_line.objects.filter(SPC_CLM_FORMAT=document_attribute_old).select_for_update():
            #         item_line.SPC_CLM_FORMAT = document_attribute.get('id')
            #         item_line.save()
            #
            #     for item_line in Item_line.objects.filter(SPC_CLM_ZONE=document_attribute_old).select_for_update():
            #         item_line.SPC_CLM_ZONE = document_attribute_old
            #         item_line.save()
            #
            #     for item_line in Item_line.objects.filter(SPC_CLM_POS=document_attribute_old).select_for_update():
            #         item_line.SPC_CLM_POS = document_attribute.get('id')
            #         item_line.save()
            #
            #     for item_line in Item_line.objects.filter(SPC_CLM_MARK=document_attribute_old).select_for_update():
            #         item_line.SPC_CLM_MARK = document_attribute.get('id')
            #         item_line.save()
            #
            #     for item_line in Item_line.objects.filter(SPC_CLM_NAME=document_attribute_old).select_for_update():
            #         item_line.SPC_CLM_NAME = document_attribute.get('id')
            #         item_line.save()
            #
            #     for item_line in Item_line.objects.filter(SPC_CLM_COUNT=document_attribute_old).select_for_update():
            #         item_line.SPC_CLM_COUNT = document_attribute.get('id')
            #         item_line.save()
            #
            #     for item_line in Item_line.objects.filter(SPC_CLM_NOTE=document_attribute_old).select_for_update():
            #         item_line.SPC_CLM_NOTE = document_attribute.get('id')
            #         item_line.save()
            #
            #     for item_line in Item_line.objects.filter(SPC_CLM_MASSA=document_attribute_old).select_for_update():
            #         item_line.SPC_CLM_MASSA = document_attribute.get('id')
            #         item_line.save()
            #
            #     for item_line in Item_line.objects.filter(SPC_CLM_MATERIAL=document_attribute_old).select_for_update():
            #         item_line.SPC_CLM_MATERIAL = document_attribute.get('id')
            #         item_line.save()
            #
            #     for item_line in Item_line.objects.filter(SPC_CLM_USER=document_attribute_old).select_for_update():
            #         item_line.SPC_CLM_USER = document_attribute.get('id')
            #         item_line.save()
            #
            #     for item_line in Item_line.objects.filter(SPC_CLM_KOD=document_attribute_old).select_for_update():
            #         item_line.SPC_CLM_KOD = document_attribute.get('id')
            #         item_line.save()
            #
            #     for item_line in Item_line.objects.filter(SPC_CLM_FACTORY=document_attribute_old).select_for_update():
            #         item_line.SPC_CLM_FACTORY = document_attribute.get('id')
            #         item_line.save()
            #     document_attribute_old.delete()

            Document_attributes.objects.filter(id=document_attribute.get('id')).update(**document_attribute)
            return document_attribute

    def updateFromRequest(self, request, removed=None, function=None):
        if not isinstance(request, DSRequest):
            request = DSRequest(request=request)
        data = request.get_data()
        return self.update_document_attributes(data)


class Document_attributes(AuditModel):
    attr_type = ForeignKeyProtect(Attr_type, verbose_name='Тип атрибута')
    value_str = TextField(verbose_name="Значение атрибута", db_index=True, null=True, blank=True)

    objects = Document_attributesManager()

    def save(self, *args, **kwargs):
        if self.value_str == None:
            try:
                Document_attributes.objects.get(value_str__isnull=True, attr_type=self.attr_type)
                raise Exception(f'Элемент с пустым значением уже существует.')
            except Document_attributes.DoesNotExist:
                pass

        super().save(*args, **kwargs)

    def __str__(self):
        return f'ID={self.id}, attr_type=[{self.attr_type}], attr_type__code=[{self.attr_type.code}], value_str={self.value_str}'

    class Meta:
        verbose_name = 'Аттрибуты докуменнта'
        unique_together = (('attr_type', 'value_str'),)



import logging

from django.core.management import BaseCommand
from django.db import transaction
from tqdm import tqdm

from isc_common import del_last_not_digit
from kaf_pas.ckk.models.item import Item
from kaf_pas.ckk.models.item_complex_view import Item_Complex_view
from kaf_pas.ckk.models.item_line import Item_line
from kaf_pas.ckk.models.item_refs import Item_refs
from kaf_pas.ckk.models.item_view import Item_view

logger = logging.getLogger(__name__)


class Command(BaseCommand):
    help = "Загрузка сборочных едениц"
    parent_list = []

    def isComplexItemTrue(self, item):
        res = Item_line.objects.filter(parent=item).count()
        return res > 0

    def isComplexItem(self, parent, child):
        try:
            item_line = Item_line.objects.get(parent=parent, child=child)
            return item_line.section == 'Сборочные единицы'
        except Item_line.DoesNotExist:
            return False

    cnt = 1

    def check_layer(self, parent=None, child_id=None, level=0):
        if not parent or (not parent.id in self.parent_list):
            if parent:
                self.parent_list.append(parent.id)
            logger.debug(f'\n\nLevel: {level}\n\n')

            if child_id:
                query = Item_view.objects.filter(
                    parent_id=parent.id if parent else None,
                    id=child_id,
                    props__in=[
                        Item.props.relevant | Item.props.from_spw,
                        Item.props.relevant | Item.props.from_spw | Item.props.for_line,
                        Item.props.relevant | Item.props.man_input
                    ]
                )
            else:
                query = Item_view.objects.filter(
                    parent_id=parent.id if parent else None,
                    props__in=[
                        Item.props.relevant | Item.props.from_spw,
                        Item.props.relevant | Item.props.from_spw | Item.props.for_line,
                        Item.props.relevant | Item.props.man_input
                    ]
                )

            for item_view in query:
                child = item_view.item
                # logger.debug(f'\n{child}')

                for item_line in Item_line.objects.filter(parent=child):
                    # logger.debug(item_line)
                    if self.isComplexItem(parent=item_line.parent, child=item_line.child):
                        if not self.isComplexItemTrue(item_line.child):
                            if item_line.child.STMP_2:
                                STMP_2 = del_last_not_digit(item_line.child.STMP_2.value_str)

                                complex_query = Item_Complex_view.objects.filter(STMP_2__value_str=STMP_2)
                                # logger.debug(f'complex_query len: {len(complex_query)}')
                                for complex_item in complex_query.distinct('STMP_2'):
                                    # logger.debug(f'\nFound complex Item: {complex_item}')

                                    item_line_new, created = Item_line.objects.get_or_create(parent=item_line.parent,
                                                                                             child=complex_item.item,
                                                                                             defaults=dict(
                                                                                                 SPC_CLM_FORMAT=item_line.SPC_CLM_FORMAT,
                                                                                                 SPC_CLM_ZONE=item_line.SPC_CLM_ZONE,
                                                                                                 SPC_CLM_POS=item_line.SPC_CLM_POS,
                                                                                                 SPC_CLM_COUNT=item_line.SPC_CLM_COUNT,
                                                                                                 SPC_CLM_NOTE=item_line.SPC_CLM_NOTE,
                                                                                                 SPC_CLM_MASSA=item_line.SPC_CLM_MASSA,
                                                                                                 SPC_CLM_MATERIAL=item_line.SPC_CLM_MATERIAL,
                                                                                                 SPC_CLM_USER=item_line.SPC_CLM_USER,
                                                                                                 SPC_CLM_KOD=item_line.SPC_CLM_KOD,
                                                                                                 SPC_CLM_FACTORY=item_line.SPC_CLM_FACTORY,
                                                                                                 SPC_CLM_NAME=complex_item.STMP_1,
                                                                                                 SPC_CLM_MARK=complex_item.STMP_2,
                                                                                                 section=item_line.section,
                                                                                                 subsection=item_line.subsection,
                                                                                             ))

                                    if created:
                                        logger.debug(f'\n#{self.cnt} Created item_line_new:{item_line_new}')
                                    else:
                                        logger.debug(f'\nn#{self.cnt} Founded item_line_new:{item_line_new}')

                                    self.cnt += 1

                                    item_refs, created = Item_refs.objects.get_or_create(parent=item_line.parent, child=complex_item.item)

                                    if created:
                                        logger.debug(f'\nCreated item_refs:{item_refs}')
                                    else:
                                        logger.debug(f'\nFounded item_refs:{item_refs}')

                                    res = Item_line.objects.filter(parent=item_line.parent, child=item_line.child).delete()
                                    # logger.debug(f'\nDeleted: {res[0]} from Item_line')
                                    res = Item_refs.objects.filter(parent=item_line.parent, child=item_line.child).delete()
                                    # logger.debug(f'\nDeleted: {res[0]} from Item_refs')
                                    break

                self.check_layer(parent=child, level=level + 1)
                logger.debug(f'\n\nLevel: {level}\n\n')

                if self.pbar:
                    self.pbar.update(1)

    def handle(self, *args, **options):

        logger.debug(self.help)

        self.pbar = tqdm(total=Item_view.objects.filter().count())

        # <editor-fold desc="Этап 3">
        with transaction.atomic():
            # self.check_layer(parent=Item.objects.get(id=3169551), child_id= 3169568)
            self.check_layer()
        logger.debug("Загрузка выполнена.")

        if self.pbar:
            self.pbar.close()

        # </editor-fold>

# with transaction.atomic():



from django.urls import path

from kaf_pas.planing.views import operations_plan_view

urlpatterns = [

    path('Operations_plan_view/Fetch/', operations_plan_view.Operations_plan_view_Fetch),
    path('Operations_plan_view/Add', operations_plan_view.Operations_plan_view_Add),
    path('Operations_plan_view/Update', operations_plan_view.Operations_plan_view_Update),
    path('Operations_plan_view/Remove', operations_plan_view.Operations_plan_view_Remove),
    path('Operations_plan_view/Lookup/', operations_plan_view.Operations_plan_view_Lookup),
    path('Operations_plan_view/Info/', operations_plan_view.Operations_plan_view_Info),
    path('Operations_plan_view/Copy', operations_plan_view.Operations_plan_view_Copy),

]



import logging

from django.core.management import BaseCommand
from django.db import transaction
from tqdm import tqdm

from kaf_pas.ckk.models.attr_type import Attr_type
from kaf_pas.ckk.models.item import Item
from kaf_pas.ckk.models.item_refs import Item_refs
from kaf_pas.kd.models.document_attributes import Document_attributes

logger = logging.getLogger(__name__)
logger1 = logging.getLogger(f'{__name__}_1')


class Command(BaseCommand):
    help = "Перенос чертежей в подпапку"

    def handle(self, *args, **options):

        logger.info(self.help)

        cdws_type, _ = Attr_type.objects.get_or_create(code='CDWS', defaults=dict(name='Чертежи'))
        cdws_attr, _ = Document_attributes.objects.get_or_create(attr_type=cdws_type, value_str='Автоматически закачанные чертежи')
        cdws_item, _ = Item.objects.get_or_create(STMP_1=cdws_attr, props=Item.props.from_cdw)

        spws_type, _ = Attr_type.objects.get_or_create(code='top_auto_level')
        spws_attr, _ = Document_attributes.objects.get_or_create(attr_type=spws_type, value_str='Автоматически сгененрированный состав изделий')
        spws_item, _ = Item.objects.get_or_create(STMP_1=spws_attr, props= Item.props.from_spw)

        cnt = 0

        for item in Item.objects.filter(props__in=[Item.props.from_cdw, Item.props.from_pdf, Item.props.from_spw]):
            try:
                Item_refs.objects.get(child=item)
            except Item_refs.MultipleObjectsReturned:
                ...
            except Item_refs.DoesNotExist:
                cnt += 1
                print(cnt)

        self.pbar = tqdm(total=cnt)

        with transaction.atomic():
            for item in Item.objects.filter(props__in=[Item.props.from_cdw, Item.props.from_pdf]):
                try:
                    Item_refs.objects.get(child=item)
                except Item_refs.MultipleObjectsReturned:
                    ...
                except Item_refs.DoesNotExist:
                    Item_refs.objects.get_or_create(child=item, parent=cdws_item)

                    if self.pbar:
                        self.pbar.update(1)

            for item in Item.objects.filter(props__in=[Item.props.from_spw]):
                try:
                    Item_refs.objects.get(child=item)
                except Item_refs.MultipleObjectsReturned:
                    ...
                except Item_refs.DoesNotExist:
                    Item_refs.objects.get_or_create(child=item, parent=spws_item)

                    if self.pbar:
                        self.pbar.update(1)

        if self.pbar:
            self.pbar.close()

        logger.info("Загрузка выполнена.")
        # </editor-fold>

# with transaction.atomic():



from django.urls import path

from kaf_pas.planing.views import operations_plan

urlpatterns = [

    path('OperationsPlan/Fetch/', operations_plan.Operations_plan_Fetch),
    path('OperationsPlan/Add', operations_plan.Operations_plan_Add),
    path('OperationsPlan/Update', operations_plan.Operations_plan_Update),
    path('OperationsPlan/Remove', operations_plan.Operations_plan_Remove),
    path('OperationsPlan/Lookup/', operations_plan.Operations_plan_Lookup),
    path('OperationsPlan/Info/', operations_plan.Operations_plan_Info),
    path('OperationsPlan/Copy', operations_plan.Operations_plan_Copy),

]



import logging

from django.db.models import DateTimeField

from crypto.models.crypto_file import Crypto_file, CryptoManager, CryptoQuerySet
from isc_common import delAttr
from isc_common.fields.code_field import CodeField
from isc_common.fields.description_field import DescriptionField
from isc_common.fields.related import ForeignKeyProtect
from isc_common.http.DSRequest import DSRequest
from kaf_pas.ckk.models.status import Status
from kaf_pas.sales.models.customer import Customer
from kaf_pas.sales.models.dogovors import Dogovors
from kaf_pas.sales.models.status_precent import StatusPrecent

logger = logging.getLogger(__name__)


class PrecentQuerySet(CryptoQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class PrecentManager(CryptoManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'code': record.code,
            'date': record.date,
            'date_sign': record.date_sign,
            'description': record.description,

            'status_id': record.status.id if record.status else None,
            'status__code': record.status.code if record.status else None,
            'status__name': record.status.name if record.status else None,

            'document_id': record.document.id if record.document else None,
            'document__code': record.document.code if record.document else None,
            'document__date': record.document.date if record.document else None,

            'format': record.format,
            'mime_type': record.mime_type,
            'size': record.size if not str(record.size).startswith('.') else str(record.size).replace('.', '0.'),
            'real_name': record.real_name,

            'lastmodified': record.lastmodified,
            'editing': record.editing,
            'deliting': record.deliting,
            'parent_id': record.parent.id if record.parent else None,
        }
        return res

    def updateFromRequest(self, request, printRequest=False):
        request = DSRequest(request=request)
        data = request.get_data()
        _data = data.copy()
        # data.update(dict(type))
        delAttr(_data, 'form')
        delAttr(_data, 'isFolder')
        super().filter(id=request.get_id()).update(**_data)
        return data

    def get_queryset(self):
        return PrecentQuerySet(self.model, using=self._db)


class Precent(Crypto_file):
    code = CodeField()
    description = DescriptionField()
    parent = ForeignKeyProtect('self', null=True, blank=True, related_name='parent_p')
    document = ForeignKeyProtect(Dogovors, null=True, blank=True, related_name='document_p')

    date = DateTimeField(verbose_name='Дата', db_index=True, null=True, blank=True)
    date_sign = DateTimeField(verbose_name='Дата подписания', db_index=True, null=True, blank=True)

    status = ForeignKeyProtect(StatusPrecent)

    objects = PrecentManager()

    def __str__(self):
        return f'{self.id}'

    class Meta:
        verbose_name = 'Документы'



import logging

from django.db.models import Model

from isc_common.fields.related import ForeignKeyProtect
from isc_common.models.audit import AuditQuerySet, AuditManager
from kaf_pas.production.models.operations import Operations

logger = logging.getLogger(__name__)


class Operations_refsQuerySet(AuditQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class Operations_refsManager(AuditManager):

    @staticmethod
    def getRecord(record):
        res = {}
        return res

    def get_queryset(self):
        return Operations_refsQuerySet(self.model, using=self._db)


class Operations_refs(Model):
    child = ForeignKeyProtect(Operations, related_name='child_Operation')
    parent = ForeignKeyProtect(Operations, related_name='parent_Operation', blank=True, null=True)


    objects = Operations_refsManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Кросс таблица'



import logging

from django.db.models import PositiveIntegerField

from isc_common.fields.related import ForeignKeyProtect
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsQuerySet, CommonManagetWithLookUpFieldsManager
from isc_common.models.audit import AuditModel
from kaf_pas.ckk.models.item import Item
from kaf_pas.ckk.models.locations import Locations
from kaf_pas.sales.models.precent import Precent

logger = logging.getLogger(__name__)


class Precent_itemsQuerySet(CommonManagetWithLookUpFieldsQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class Precent_itemsManager(CommonManagetWithLookUpFieldsManager):

    @staticmethod
    def getRecord(record):
        res = {
            "id": record.id,
            'item_id': record.item.id,
            'item__STMP_1': record.item.STMP_1.value_str if record.item.STMP_1 else None,
            'item__STMP_2': record.item.STMP_2.value_str if record.item.STMP_2 else None,
            'location_id': record.location.id if record.location else None,
            'location__code': record.location.code if record.location else None,
            'location__name': record.location.name if record.location else None,
            'precent_id': record.precent.id,
            'qty': record.qty,
            "lastmodified": record.lastmodified,
            "editing": record.editing,
            "deliting": record.deliting,
        }
        return res

    def get_queryset(self):
        return Precent_itemsQuerySet(self.model, using=self._db)


class Precent_items(AuditModel):
    item = ForeignKeyProtect(Item)
    precent = ForeignKeyProtect(Precent)
    location = ForeignKeyProtect(Locations, null=True, blank=True)
    qty = PositiveIntegerField()

    objects = Precent_itemsManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Комплектация распоряжения'
        # unique_together = (('item', 'precent'),)



from django.urls import path

from kaf_pas.ckk.views import item_view

urlpatterns = [

    path('ItemView/Fetch/', item_view.Item_view_Fetch),
    path('ItemView/Add', item_view.Item_view_Add),
    path('ItemView/Update', item_view.Item_view_Update),
    path('ItemView/Remove', item_view.Item_view_Remove),
    path('ItemView/Lookup/', item_view.Item_view_Lookup),
    path('ItemView/Info/', item_view.Item_view_Info),
    path('CopyItems', item_view.copyItems),

]



import logging

from django.db.models import DecimalField

from isc_common.fields.related import ForeignKeyProtect
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
from isc_common.models.audit import AuditModel
from kaf_pas.planing.models.operations_plan import OperationsPlan

logger = logging.getLogger(__name__)


class Operations_plan_sumsQuerySet(CommonManagetWithLookUpFieldsQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class Operations_plan_sumsManager(CommonManagetWithLookUpFieldsManager):

    @staticmethod
    def getRecord(record):
        res = {}
        return res

    def get_queryset(self):
        return Operations_plan_sumsQuerySet(self.model, using=self._db)


class Operations_plan_qtys(AuditModel):
    quantity = DecimalField(max_digits=20, decimal_places=8)
    operations_plan = ForeignKeyProtect(OperationsPlan)
    objects = Operations_plan_sumsManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Суммы'



import logging

from django.db.models import BooleanField

from isc_common.models.audit import AuditManager, AuditQuerySet
from kaf_pas.planing.models.operations_plan import OperationsPlan

logger = logging.getLogger(__name__)


class Operations_plan_viewQuerySet(AuditQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class Operations_plan_viewManager(AuditManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'code': record.code,
            'name': record.name,
            'description': record.description,
            'isFolder': record.isFolder,
        }
        return res

    def get_queryset(self):
        return Operations_plan_viewQuerySet(self.model, using=self._db)


class Operations_plan_view(OperationsPlan):
    isFolder = BooleanField()

    objects = Operations_plan_viewManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        db_table = 'production_operationsplan_view'
        managed = False
        verbose_name = 'Операции планировая'



import logging

from isc_common.fields.related import ForeignKeyProtect
from isc_common.models.audit import AuditQuerySet, AuditManager
from isc_common.models.base_ref import BaseRef, BaseRefHierarcy, BaseRefManager, BaseRefQuerySet

logger = logging.getLogger(__name__)


class locationsQuerySet(BaseRefQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class LocationsManager(BaseRefManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'code': record.code,
            'name': record.name,
            'full_name': record.full_name,
            'description': record.description,
            'parent_id': record.parent.id if record.parent else None
        }
        return res

    def get_queryset(self):
        return locationsQuerySet(self.model, using=self._db)


class Locations(BaseRefHierarcy):
    objects = LocationsManager()


def __str__(self):
    return f"{self.id}"


class Meta:
    verbose_name = 'Место положения'



import logging

from django.db.models import PositiveIntegerField

from isc_common.fields.related import ForeignKeyProtect
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsQuerySet, CommonManagetWithLookUpFieldsManager
from isc_common.models.audit import AuditModel
from kaf_pas.ckk.models.ed_izm import Ed_izm
from kaf_pas.ckk.models.materials import Materials
from kaf_pas.sales.models.precent import Precent

logger = logging.getLogger(__name__)


class Precent_materialsQuerySet(CommonManagetWithLookUpFieldsQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class Precent_materialsManager(CommonManagetWithLookUpFieldsManager):

    @staticmethod
    def getRecord(record):
        res = {
            "id": record.id,
            'material_id': record.material.id,
            'material__code': record.material.code,
            'material__name': record.material.name,
            'qty': record.qty,
            "lastmodified": record.lastmodified,
            "editing": record.editing,
            "deliting": record.deliting,
        }
        return res

    def get_queryset(self):
        return Precent_materialsQuerySet(self.model, using=self._db)


class Precent_materials(AuditModel):
    precent = ForeignKeyProtect(Precent)
    material = ForeignKeyProtect(Materials)
    objects = Precent_materialsManager()
    qty = PositiveIntegerField()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Кросс таблица'



# Generated by Django 2.2.3 on 2019-07-30 13:50

import bitfield.models
from django.db import migrations, models
import django.utils.timezone
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0076_pathes_virt_path'),
    ]

    operations = [
        migrations.CreateModel(
            name='Documents_mview',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('relevant', isc_common.fields.code_field.CodeField(blank=True, null=True, verbose_name='Актуальность')),
                ('file_document', models.TextField(verbose_name='Полный путь к файлу')),
                ('file_size', models.PositiveIntegerField(verbose_name='Размер файла')),
                ('file_modification_time', models.DateTimeField(blank=True, null=True, verbose_name='Дата время поcледнего модификации документа')),
                ('file_access_time', models.DateTimeField(blank=True, null=True, verbose_name='Дата время поcледнего доступа к документу')),
                ('file_change_time', models.DateTimeField(blank=True, null=True, verbose_name='Дата время изменнения документа')),
                ('props', bitfield.models.BitField((('relevant', 'Актуальность'), ('beenItemed', 'Был внесен в состав изделий')), default=1)),
                ('load_error', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'Documents MView',
                'db_table': 'kd_documents_mview',
                'managed': False,
            },
        ),
    ]



import logging

from django.db.models import Model

from isc_common.fields.related import ForeignKeyProtect
from kaf_pas.planing.models.operations_plan import OperationsPlan

logger = logging.getLogger(__name__)


class Operations_plan_refs(Model):
    child = ForeignKeyProtect(OperationsPlan, related_name='child_Operations_plan')
    parent = ForeignKeyProtect(OperationsPlan, related_name='parent_Operations_plan', blank=True, null=True)

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Кросс таблица'



import logging

from django.db.models import PositiveIntegerField
from django.forms import model_to_dict

from isc_common import delAttr
from isc_common.fields.related import ForeignKeyProtect
from isc_common.http.DSRequest import DSRequest
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsQuerySet, CommonManagetWithLookUpFieldsManager
from isc_common.models.base_ref import Hierarcy
from kaf_pas.ckk.models.ed_izm import Ed_izm
from kaf_pas.ckk.models.item import Item
from kaf_pas.production.models.operations import Operations

logger = logging.getLogger(__name__)


class Operations_itemQuerySet(CommonManagetWithLookUpFieldsQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class Operations_itemManager(CommonManagetWithLookUpFieldsManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'operation_id': record.operation.id,
            'operation__code': record.operation.code,
            'operation__name': record.operation.name,
            'operation__full_name': record.operation.full_name,
            'operation__description': record.operation.description,
            'ed_izm_id': record.ed_izm.id if record.ed_izm else None,
            'ed_izm__code': record.ed_izm.code if record.ed_izm else None,
            'ed_izm__name': record.ed_izm.name if record.ed_izm else None,
            'ed_izm__description': record.ed_izm.description if record.ed_izm else None,
            'qty': record.qty,
            'parent_id': record.parent.id if record.parent else None
        }
        return res

    def get_queryset(self):
        return Operations_itemQuerySet(self.model, using=self._db)

    def createFromRequest(self, request):
        request = DSRequest(request=request)
        data = request.get_data()
        _data = data.copy()
        delAttr(_data, 'operation__full_name')

        res = super().create(**_data)
        res = model_to_dict(res)

        data.update(res)
        return data

    def updateFromRequest(self, request):
        request = DSRequest(request=request)
        data = request.get_data()
        _data = data.copy()

        delAttr(_data, 'operation__full_name')
        super().update_or_create(id=data.get('id'), defaults=_data)

        return data


class Operations_item(Hierarcy):
    item = ForeignKeyProtect(Item)
    operation = ForeignKeyProtect(Operations)
    ed_izm = ForeignKeyProtect(Ed_izm, default=None, null=True, blank=True)
    qty = PositiveIntegerField(default=None, null=True, blank=True)

    objects = Operations_itemManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Кросс таблица'



# Generated by Django 2.2 on 2019-04-12 20:45

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0008_auto_20190328_1104'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='item_line',
            name='parent',
        ),
        migrations.CreateModel(
            name='Item_line_refs',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted', models.BooleanField(db_index=True, default=False, verbose_name='Признак удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('child', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='child', to='ckk.Item_line')),
                ('parent', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='parent', to='ckk.Item_line')),
            ],
            options={
                'verbose_name': 'Item_line_refs',
            },
        ),
    ]



from django.urls import path

from kaf_pas.planing.views import operation_plan_types

urlpatterns = [

    path('OperationPlanTypes/Fetch/', operation_plan_types.Operation_plan_types_Fetch),
    path('OperationPlanTypes/Add', operation_plan_types.Operation_plan_types_Add),
    path('OperationPlanTypes/Update', operation_plan_types.Operation_plan_types_Update),
    path('OperationPlanTypes/Remove', operation_plan_types.Operation_plan_types_Remove),
    path('OperationPlanTypes/Lookup/', operation_plan_types.Operation_plan_types_Lookup),
    path('OperationPlanTypes/Info/', operation_plan_types.Operation_plan_types_Info),
    path('OperationPlanTypes/Copy', operation_plan_types.Operation_plan_types_Copy),

]



import logging

from isc_common.fields.related import ForeignKeyCascade
from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
from kaf_pas.ckk.models.item import Item
from kaf_pas.production.models.operations import Operations

logger = logging.getLogger(__name__)


class Item_operationsQuerySet(AuditQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class Item_operationsManager(AuditManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'code': record.code,
            'name': record.name,
            'description': record.description,
        }
        return res

    def get_queryset(self):
        return Item_operationsQuerySet(self.model, using=self._db)


class Item_operations(AuditModel):
    item = ForeignKeyCascade(Item)
    operation = ForeignKeyCascade(Operations)

    objects = Item_operationsManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Кросс таблица'



import logging

from django.db import transaction
from isc_common.fields.related import ForeignKeyCascade
from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
from kaf_pas.kd.models.pathes import Pathes

logger = logging.getLogger(__name__)


class UploadesQuerySet(AuditQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class UploadesManager(AuditManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'lastmodified': record.lastmodified,
            'path_id': record.path.id,
            'absolute_path': record.path.absolute_path
        }
        return res

    def get_queryset(self):
        return UploadesQuerySet(self.model, using=self._db)

    def deleteFromRequest(self, request):
        from kaf_pas.kd.models.uploades_documents import Uploades_documents
        from kaf_pas.kd.models.documents_thumb import Documents_thumb
        from kaf_pas.kd.models.documents_thumb10 import Documents_thumb10
        from kaf_pas.kd.models.document_attr_cross import Document_attr_cross
        from kaf_pas.ckk.models.item import Item
        from kaf_pas.ckk.models.item import ItemManager
        from kaf_pas.kd.models.documents_history import Documents_history
        from kaf_pas.kd.models.documents import Documents
        from kaf_pas.kd.models.uploades_log import Uploades_log

        ids = request.GET.getlist('ids')

        res = 0
        with transaction.atomic():
            for i in range(0, len(ids), 2):
                id = ids[i]
                visibleMode = ids[i + 1]

                if visibleMode != "none":
                    res += super().filter(id=id).soft_delete(visibleMode=visibleMode)
                else:
                    for upload_document in Uploades_documents.objects.filter(upload_id=id):

                        Document_attr_cross.objects.filter(document=upload_document.document).delete()

                        for item in Item.objects.filter(document=upload_document.document):
                            ItemManager.delete_recursive(item, True)

                        for documents_history in Documents_history.objects.filter(new_document=upload_document.document):
                            documents_history.old_document.props |= Documents.props.relevant
                            documents_history.old_document.save()
                            documents_history.delete()

                        Documents_thumb.objects.filter(document=upload_document.document).delete()
                        Documents_thumb10.objects.filter(document=upload_document.document).delete()
                        document = Documents.objects.get(id=upload_document.document.id)
                        logger.debug(f'Deliting: {document}')
                        document.delete()
                        logger.debug('Done.')
                    Uploades_log.objects.filter(upload_id=id).delete()
                    res += super().filter(id=id).delete()[0]
        return res


class Uploades(AuditModel):
    path = ForeignKeyCascade(Pathes)
    objects = UploadesManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Загрузки внешних данных'



import logging

from isc_common.fields.related import ForeignKeyProtect
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
from isc_common.models.audit import AuditModel
from kaf_pas.production.models.operations import Operations
from kaf_pas.production.models.resource import Resource

logger = logging.getLogger(__name__)


class Operation_resourcesQuerySet(CommonManagetWithLookUpFieldsQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class Operation_resourcesManager(CommonManagetWithLookUpFieldsManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'operation_id': record.operation.id,
            'resource_id': record.resource.id,
            'resource__code': record.resource.code,
            'resource__name': record.resource.name,
            'resource__full_name': record.resource.full_name,
            'complex_name': record.complex_name,
        }
        return res

    def get_queryset(self):
        return Operation_resourcesQuerySet(self.model, using=self._db)


class Operation_resources(AuditModel):
    operation = ForeignKeyProtect(Operations)
    resource = ForeignKeyProtect(Resource)

    @property
    def complex_name(self):
        return f'{self.resource.location.full_name}{self.resource.full_name}'

    objects = Operation_resourcesManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Кросс таблица'
